<?php

namespace Simple\SiteBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Simple\SiteBundle\Entity\Oddzial;
use Simple\SiteBundle\Form\OddzialType;

/**
 * Oddzial controller.
 *
 * @Route("/oddzial")
 */
class OddzialController extends Controller
{
    /**
     * Lists all Oddzial entities.
     *
     * @Route("/", name="oddzial")
     * @Template()
     */
    public function indexAction()
    {
        $em = $this->getDoctrine()->getEntityManager();

        $entities = $em->getRepository('SimpleSiteBundle:Oddzial')->findAll();

        return array('entities' => $entities);
    }

    /**
     * Finds and displays a Oddzial entity.
     *
     * @Route("/{id}/show", name="oddzial_show")
     * @Template()
     */
    public function showAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();

        $entity = $em->getRepository('SimpleSiteBundle:Oddzial')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Oddzial entity.');
        }

        $deleteForm = $this->createDeleteForm($id);

        return array(
            'entity'      => $entity,
            'delete_form' => $deleteForm->createView(),        );
    }

    /**
     * Displays a form to create a new Oddzial entity.
     *
     * @Route("/new", name="oddzial_new")
     * @Template()
     */
    public function newAction()
    {
        $entity = new Oddzial();
        $form   = $this->createForm(new OddzialType(), $entity);

        return array(
            'entity' => $entity,
            'form'   => $form->createView()
        );
    }

    /**
     * Creates a new Oddzial entity.
     *
     * @Route("/create", name="oddzial_create")
     * @Method("post")
     * @Template("SimpleSiteBundle:Oddzial:new.html.twig")
     */
    public function createAction()
    {
        $entity  = new Oddzial();
        $request = $this->getRequest();
        $form    = $this->createForm(new OddzialType(), $entity);
        $form->bindRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getEntityManager();
            $em->persist($entity);
            $em->flush();

            return $this->redirect($this->generateUrl('oddzial_show', array('id' => $entity->getId())));
            
        }

        return array(
            'entity' => $entity,
            'form'   => $form->createView()
        );
    }

    /**
     * Displays a form to edit an existing Oddzial entity.
     *
     * @Route("/{id}/edit", name="oddzial_edit")
     * @Template()
     */
    public function editAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();

        $entity = $em->getRepository('SimpleSiteBundle:Oddzial')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Oddzial entity.');
        }

        $editForm = $this->createForm(new OddzialType(), $entity);
        $deleteForm = $this->createDeleteForm($id);

        return array(
            'entity'      => $entity,
            'edit_form'   => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        );
    }

    /**
     * Edits an existing Oddzial entity.
     *
     * @Route("/{id}/update", name="oddzial_update")
     * @Method("post")
     * @Template("SimpleSiteBundle:Oddzial:edit.html.twig")
     */
    public function updateAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();

        $entity = $em->getRepository('SimpleSiteBundle:Oddzial')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Oddzial entity.');
        }

        $editForm   = $this->createForm(new OddzialType(), $entity);
        $deleteForm = $this->createDeleteForm($id);

        $request = $this->getRequest();

        $editForm->bindRequest($request);

        if ($editForm->isValid()) {
            $em->persist($entity);
            $em->flush();

            return $this->redirect($this->generateUrl('oddzial_edit', array('id' => $id)));
        }

        return array(
            'entity'      => $entity,
            'edit_form'   => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        );
    }

    /**
     * Deletes a Oddzial entity.
     *
     * @Route("/{id}/delete", name="oddzial_delete")
     * @Method("post")
     */
    public function deleteAction($id)
    {
        $form = $this->createDeleteForm($id);
        $request = $this->getRequest();

        $form->bindRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getEntityManager();
            $entity = $em->getRepository('SimpleSiteBundle:Oddzial')->find($id);

            if (!$entity) {
                throw $this->createNotFoundException('Unable to find Oddzial entity.');
            }

            $em->remove($entity);
            $em->flush();
        }

        return $this->redirect($this->generateUrl('oddzial'));
    }

    private function createDeleteForm($id)
    {
        return $this->createFormBuilder(array('id' => $id))
            ->add('id', 'hidden')
            ->getForm()
        ;
    }
}
